package com.ruoyi.frequency.vote.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.controller.req.VoteReq;
import com.ruoyi.frequency.vote.entity.Vote;
import com.ruoyi.frequency.vote.model.result.VoteCount;
import com.ruoyi.response.ResponseData;
import com.ruoyi.vo.PageBasic;
import com.ruoyi.vo.UserVo;

import java.util.List;

/**
 * 投票活动Service接口
 *
 * @author liwenlong
 * @date 2023-10-12
 */
public interface VoteService extends IService<Vote>
{
    /**
     * 查询投票活动
     *
     * @param id 投票活动主键
     * @return 投票活动
     */
    public Vote selectVoteById(Long id);

    /**
     * 查询投票活动列表
     *
     * @param vote 投票活动
     * @return 投票活动集合
     */
    public List<Vote> selectVoteList(Vote vote);

    VoteCount statistics(Vote vote);

    /**
     * 新增投票活动
     *
     * @param vote 投票活动
     * @return 结果
     */
    public int insertVote(Vote vote);

    /**
     * 修改投票活动
     *
     * @param vote 投票活动
     * @return 结果
     */
    public int updateVote(Vote vote);

    /**
     * 批量删除投票活动
     *
     * @param ids 需要删除的投票活动主键集合
     * @return 结果
     */
    public int deleteVoteByIds(Long[] ids, Integer delFlag);

    /**
     * 删除投票活动信息
     *
     * @param id 投票活动主键
     * @return 结果
     */
    public int deleteVoteById(Long id);


    /**
     * 投票列表
     * @param req
     * @param userVo
     * @param isSelf 是否查询自己投票
     * @return
     */
    ResponseData votePage(PageBasic req, UserVo userVo,boolean isSelf);


    /**
     * 投票
     * @param req
     * @param userVo
     * @return
     */
    ResponseData vote(VoteReq req, UserVo userVo);


    /**
     * 投票详情
     * @param req
     * @param userVo
     * @return
     */
    ResponseData voteDetail(Long voteId, Integer isAddBrowseNum,UserVo userVo);

}
